==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/th-TH/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'หมวดหมู่ทรัพย์สิน',
    'category_name'  					=> 'ชื่อหมวดหมู่',
    'checkin_email'                     => 'ส่งอีเมลไปยังผู้ใช้เมื่อเช็คอิน / เช็คเอาต์',
    'checkin_email_notification'        => 'ผู้ใช้รายนี้จะได้รับอีเมลเกี่ยวกับเช็คอิน / เช็คเอาท์',
    'clone'                             => 'คัดลอกหมวดหมู่',
    'create'  							=> 'สร้างหมวดหมู่',
    'edit'                              => 'แก้ไขหมวดหมู่',
    'email_will_be_sent_due_to_global_eula' => 'An email will be sent to the user because the global EULA is being used.',
    'email_will_be_sent_due_to_category_eula' => 'An email will be sent to the user because a EULA is set for this category.',
    'eula_text'							=> 'หมวดหมู่ข้อกำหนดการใช้งาน',
    'eula_text_help'					=> 'ส่วนนี้อนุญาตให้คุณสามารถทำการปรับแต่งข้อตกลงการใช้งานสำหรับกำหนดชนิดของทรัพย์สินได้ หากคุณมีข้อตกลงการใช้งานเพียงหนึ่ง หรือเรื่องเดียวที่ใช้ครอบคลุมทรัพย์สินของคุณทั้งหมด คุณสามารถตั้งค่าให้เป็นการใช้งานหลัก โดยการทำเครื่องหมายในช่องด้านล่างนี้',
    'name'                              => 'ชื่อหมวดหมู่',
    'require_acceptance'				=> 'กำหนดให้ผู้ใช้ยืนยันยอมรับสินทรัพย์ในหมวดหมู่นี้',
    'required_acceptance'				=> 'ผู้ใช้นี้จะสามารถส่งอีเมล ด้วยลิงค์เพื่อการยืนยันยอมรับรายการนี้',
    'required_eula'						=> 'ผู้ใช้นี้จะส่งอีเมลสำเนาของ EULA',
    'no_default_eula'					=> 'ไม่พบข้อกำหนดการใช้งานหลักใดๆ ในการตั้งค่า',
    'update'  							=> 'ปรับปรุงแก้ไขหมวดหมู่',
    'use_default_eula'					=> 'ใช้<a href="#" data-toggle="modal" data-target="#eulaModal">เป็นข้อกำหนดการใช้งานหลัก</a>แทน.',
    'use_default_eula_disabled'			=> '<del>ใช้ค่าเริ่มต้นข้อกำหนดการใช้งานหลักแทน</del> ค่าเริ่มต้นหลักของข้อกำหนดการใช้งานไม่ได้ถูกตั้งค่าไว้ กรุณาเพิ่มในการตั้งค่า',
    'use_default_eula_column'			=> 'ใช้ค่าเริ่มต้น EULA',

);

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/th-TH/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'หมวดหมู่ทรัพย์สิน',
    'category_name'  					=> 'ชื่อหมวดหมู่',
    'checkin_email'                     => 'ส่งอีเมลไปยังผู้ใช้เมื่อเช็คอิน / เช็คเอาต์',
    'email_to_initiator'                => 'Send email to you when user accepts or declines checkout.',
    'checkin_email_notification'        => 'ผู้ใช้รายนี้จะได้รับอีเมลเกี่ยวกับเช็คอิน / เช็คเอาท์',
    'clone'                             => 'คัดลอกหมวดหมู่',
    'create'  							=> 'สร้างหมวดหมู่',
    'edit'                              => 'แก้ไขหมวดหมู่',
    'email_will_be_sent_due_to_global_eula' => 'อีเมลจะถูกส่งไปยังผู้ใช้เนื่องจากมีการใช้งาน EULA ทั่วโลก',
    'email_will_be_sent_due_to_category_eula' => 'อีเมลจะถูกส่งไปยังผู้ใช้เนื่องจากมีการตั้งค่า EULA สำหรับหมวดหมู่นี้',
    'eula_text'							=> 'หมวดหมู่ข้อกำหนดการใช้งาน',
    'eula_text_help'					=> 'ส่วนนี้อนุญาตให้คุณสามารถทำการปรับแต่งข้อตกลงการใช้งานสำหรับกำหนดชนิดของทรัพย์สินได้ หากคุณมีข้อตกลงการใช้งานเพียงหนึ่ง หรือเรื่องเดียวที่ใช้ครอบคลุมทรัพย์สินของคุณทั้งหมด คุณสามารถตั้งค่าให้เป็นการใช้งานหลัก โดยการทำเครื่องหมายในช่องด้านล่างนี้',
    'name'                              => 'ชื่อหมวดหมู่',
    'require_acceptance'				=> 'กำหนดให้ผู้ใช้ยืนยันยอมรับสินทรัพย์ในหมวดหมู่นี้',
    'required_acceptance'				=> 'ผู้ใช้นี้จะสามารถส่งอีเมล ด้วยลิงค์เพื่อการยืนยันยอมรับรายการนี้',
    'required_eula'						=> 'ผู้ใช้นี้จะส่งอีเมลสำเนาของ EULA',
    'no_default_eula'					=> 'ไม่พบข้อกำหนดการใช้งานหลักใดๆ ในการตั้งค่า',
    'update'  							=> 'ปรับปรุงแก้ไขหมวดหมู่',
    'use_default_eula'					=> 'ใช้<a href="#" data-toggle="modal" data-target="#eulaModal">เป็นข้อกำหนดการใช้งานหลัก</a>แทน.',
    'use_default_eula_disabled'			=> '<del>ใช้ค่าเริ่มต้นข้อกำหนดการใช้งานหลักแทน</del> ค่าเริ่มต้นหลักของข้อกำหนดการใช้งานไม่ได้ถูกตั้งค่าไว้ กรุณาเพิ่มในการตั้งค่า',
    'use_default_eula_column'			=> 'ใช้ค่าเริ่มต้น EULA',
    'import_require_acceptance'         => 'Require Acceptance',
    'import_checkin_email'              => 'Send Checkin Email',
    'import_eula_text'                  => 'EULA text',
    'import_category_type'              => 'Category Type',

);
